# The geolite databases were traditionally updated on the first Tuesday of each month.
# hence we use a versioning scheme of YYYY.MM for the %{_real_vendor} package.
# No further releases of IPv4 GeoLite Legacy databases will be made from April 2018.
# See https://support.maxmind.com/geolite-legacy-discontinuation-notice/
# IPv6 databases were updated in October 2018.
#
# Update this date to fetch new version of the geoip database files
%define dat_date 2018.10

%define oname GeoIP

%define major 1
%define libname %mklibname geoip %{major}
%define develname %mklibname geoip -d

Summary:	Find what country an IP address or hostname originates from
Name:		geoip
Version:	1.6.12
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		http://dev.maxmind.com/geoip/
Source0:	https://github.com/maxmind/geoip-api-c/releases/download/v%{version}/%{oname}-%{version}.tar.gz
Source1:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCountry/%{oname}.dat.gz#/%{oname}-%{dat_date}.dat.gz
Source2:	http://geolite.maxmind.com/download/geoip/database/LICENSE.txt
Source3:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.xz#/GeoLiteCity-%{dat_date}.dat.xz
Source4:	http://geolite.maxmind.com/download/geoip/database/asnum/GeoIPASNum.dat.gz#/GeoIPASNum-%{dat_date}.dat.gz
Source5:	http://geolite.maxmind.com/download/geoip/database/GeoIPv6.dat.gz#/GeoIPv6-%{dat_date}.dat.gz
Source6:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCityv6-beta/GeoLiteCityv6.dat.gz#/GeoLiteCityv6-%{dat_date}.dat.gz
Source7:	http://download.maxmind.com/download/geoip/database/asnum/GeoIPASNumv6.dat.gz#/GeoIPASNumv6-%{dat_date}.dat.gz
BuildRequires:	pkgconfig(zlib)
Requires: %{libname}

%description
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%package -n	%{libname}
Summary:	Shared library part of GeoIP
Group:		System/Libraries

%description -n	%{libname}
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%package -n	%{develname}
Summary:	Headers and libraries needed for GeoIP development
Group:		Development/Libraries
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}
Provides:	%{oname}-devel = %{version}
Obsoletes:	%{mklibname geoip 1 -d}

%description -n	%{develname}
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%prep
%setup -q -n %{oname}-%{version}

zcat %{SOURCE1} > data/GeoIP.dat
cp   %{SOURCE2} LICENSE.txt
xzcat %{SOURCE3} > data/GeoLiteCity.dat
zcat %{SOURCE4} > data/GeoIPASNum.dat
zcat %{SOURCE5} > data/GeoIPv6.dat
zcat %{SOURCE6} > data/GeoLiteCityv6.dat
zcat %{SOURCE7} > data/GeoIPASNumv6.dat

%build
autoreconf -fi
%configure2_5x --disable-static
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/cron.monthly
mkdir -p %{buildroot}%{_datadir}/GeoIP
install -m0644 data/*.dat %{buildroot}%{_datadir}/GeoIP/

# don't ship .la
find %{buildroot} -name '*.la' -exec rm -f '{}' \;

%files
%doc AUTHORS COPYING ChangeLog README.md LICENSE.txt
%{_bindir}/geoiplookup
%{_bindir}/geoiplookup6
%{_mandir}/man1/geoiplookup.1*
%{_mandir}/man1/geoiplookup6.1*
%{_datadir}/GeoIP/

%files -n %{libname}
%{_libdir}/libGeoIP.so.%{major}*

%files -n %{develname}
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%changelog
* Sun Jul 07 2019 tex - 1.6.12-1pclos2019
- rebuild against updates

